@@ -9,7 +9,7 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 {
-  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.022';
+  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.024';
 }
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
@@ -41,6 +41,8 @@ use Dist::Zilla::Plugin::InstallRelease             ( );
 use Dist::Zilla::Plugin::MetaConfig                 ( );
 use Dist::Zilla::Plugin::MetaJSON                   ( );
 use Dist::Zilla::Plugin::MetaYAML                   ( );
+use Dist::Zilla::Plugin::MetaNoIndex                ( );
+use Dist::Zilla::Plugin::MetaProvides::Package      ( );
 use Dist::Zilla::Plugin::MinimumPerl                ( );
 use Dist::Zilla::Plugin::NoSmartCommentsTests       ( );
 use Dist::Zilla::Plugin::NoTabsTests                ( );
@@ -94,10 +96,11 @@ sub release_plugins {
 
     return (
         qw{
+            TestRelease
+            ConfirmRelease
             UploadToCPAN
-            GitHub::Meta
             CheckPrereqsIndexed
-        } ,
+        },
         [ 'GitHub::Update' => { metacpan => 1 } ],
         [ ArchiveRelease => {
             directory => 'releases',
@@ -129,6 +132,17 @@ sub author_tests {
 }
 
 
+sub meta_provider_plugins {
+    my ($self) = @_;
+
+    return (
+        qw{ GitHub::Meta MetaConfig MetaJSON MetaYAML },
+        [ MetaNoIndex => { directory => [ qw{ corpus t } ] } ],
+        'MetaProvides::Package',
+    );
+}
+
+
 sub configure {
     my $self = shift @_;
 
@@ -178,15 +192,9 @@ sub configure {
         qw{
             MinimumPerl
             ReportVersions::Tiny
-
-            MetaConfig
-            MetaJSON
-            MetaYAML
-
-            TestRelease
-            ConfirmRelease
         },
 
+        $self->meta_provider_plugins,
         $self->release_plugins,
 
         ($self->is_task ? 'TaskWeaver' : $podweaver),
@@ -243,7 +251,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.022 of Dist::Zilla::PluginBundle::RSRCHBOY - released June 06, 2012 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.024 of Dist::Zilla::PluginBundle::RSRCHBOY - released June 20, 2012 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
@@ -268,6 +276,10 @@ Plugin configuration for public release.
 
 =head2 author_tests
 
+=head2 meta_provider_plugins
+
+Plugins that mess about with what goes into META.*.
+
 =head2 configure
 
 Preps plugin lists / config; see L<Dist::Zilla::Role::PluginBundle::Easy>.
